==> owncloud-app-calendar-1%3A1.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/tr.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Takvim",
    "Individual" : "Bireysel",
    "Group" : "Grup",
    "Resource" : "Kaynak",
    "Room" : "Oda",
    "Unknown" : "Bilinmeyen",
    "Required" : "Gerekli",
    "Optional" : "İsteğe Bağlı",
    "Does not attend" : "Katılmıyor",
    "New event" : "Yeni etkinli",
    "Attendees" : "Katılanlar",
    "Reminders" : "Hatırlatıcılar",
    "Repeating" : "Tekrarlama",
    "When shared show full event" : "Paylaşıldığında etkinliği göster",
    "When shared show only busy" : "Paylaşıldğında sadece meşgulleri göster",
    "When shared hide this event" : "Paylaşıldığında bu etkinliği gizle",
    "Please add a title!" : "Lütfen bir başlık ekleyin!",
    "Please select a calendar!" : "Lütfen bir takvim seçin!",
    "Global" : "Evrensel",
    "None" : "Hiçbiri",
    "Every day" : "Her gün",
    "Every week" : "Her hafta",
    "Every month" : "Her ay",
    "Every year" : "Her yıl",
    "never" : "hiçbir zaman",
    "after" : "şundan sonra",
    "At time of event" : "Olay anında",
    "5 minutes before" : "5 dakika önce",
    "10 minutes before" : "10 dakika önce",
    "15 minutes before" : "15 dakika önce",
    "30 minutes before" : "30 dakika önce",
    "1 hour before" : "1 saat önce",
    "2 hours before" : "2 saat önce",
    "Custom" : "Özel",
    "Audio" : "Ses",
    "E Mail" : "E-posta",
    "Pop up" : "Açılır pencere",
    "sec" : "saniye",
    "min" : "dk",
    "hours" : "saat",
    "days" : "gün",
    "week" : "hafta",
    "before" : "şundan önce",
    "start" : "başlangıç",
    "end" : "bitiş",
    "Editing reminders of uknown type not supported." : "Bilinmeyen tür hatırlatıcılarının düzenlenmesi desteklenmiyor.",
    "Week {number} of {year}" : "{year} yılının {number}. haftası",
    "Successfully imported" : "Başarıyla içe aktarıldı",
    "Partially imported, 1 failure" : "Kısmen içe aktarıldı, 1 başarısız",
    "Partially imported, {n} failures" : "Kısmen içe aktarıldı, {n} başarısız",
    "Audio alarm" : "Sesli alarm",
    "Pop-up" : "Açılır pencere",
    "E-Mail" : "E-Posta",
    "{type} {time} before the event starts" : "Etkinlik başlamadan {time} önce {type}",
    "{type} {time} before the event ends" : "Etkinlik bitmeden {time} önce {type}",
    "{type} {time} after the event starts" : "Etkinlik başladıktan {time} sonra {type}",
    "{type} {time} after the event ends" : "Etkinlik bittikten {time} sonra {type}",
    "{type} at the event's start" : "Etkinlik başlangıcında {type}",
    "{type} at the event's end" : "Etkinlik bitiminde {type}",
    "{type} at {time}" : "{time} zamanında {type}",
    "{calendar} shared by {owner}" : "{owner} tarafından paylaşılmış {calendar}",
    "Title of the Event" : "Etkinlik Başlığı",
    "starts" : "başlangıç",
    "ends" : "bitiş",
    "All day Event" : "Tüm gün etkinliği",
    "Location" : "Konum",
    "Delete" : "Sil",
    "Cancel" : "İptal",
    "More ..." : "Daha fazla ...",
    "Create" : "Oluştur",
    "Update" : "Güncelle",
    "Close" : "Kapat",
    "Description" : "Açıklama",
    "Export" : "Dışa aktar",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Üst yazılım hatası nedeniyle, takvim şu anda asset pipeline özelliğine destek veremiyor.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Lütfen yöneticinizle iletişime geçip \"asset-pipeline.enabled\" yapılandırma seçeneğinin devre dışı bırakılmasını talep edin.",
    "Day" : "Gün",
    "Week" : "Hafta",
    "Month" : "Ay",
    "Today" : "Bugün",
    "Share Calendar" : "Takvimi Paylaş",
    "More" : "Daha fazla",
    "Edit" : "Düzenle",
    "group" : "grup",
    "New Calendar" : "Yeni Takvim",
    "Subscriptions" : "Abonelikler",
    "New Subscription" : "Yeni Abonelik",
    "Url" : "Adres",
    "Edit event" : "Etkinliği düzenle",
    "Delete Event" : "Etkinliği Sil",
    "Save Event" : "Etkinliği Kaydet",
    "Time" : "Zaman",
    "Type" : "Tür",
    "Relative" : "Bağıl",
    "Absolute" : "Kesin",
    "Repeat" : "Tekrarla",
    "times every" : "defa, her",
    "Add" : "Ekle",
    "E-Mail address of attendee" : "Katılımcının e-posta adresi",
    "Please add your email address in the personal settings in order to add attendees." : "Lütfen katılımcıları eklemek için kişisel ayarlardan e-posta adresinizi ekleyin.",
    "from" : "başlangıç",
    "to" : "bitiş",
    "This event's repeating rule is not supported yet." : "Bu etkinliğin tekrarlanma kuralı henüz desteklenmiyor.",
    "Support for advanced rules will be added with subsequent updates." : "Gelişmiş kurallar sonraki güncellemelerde eklenecektir.",
    "Reset repeating rule" : "Tekrarlama kuralını sıfırla",
    "Repeat every ..." : "Tekrarlama koşulu...",
    "end repeat ..." : "tekrarlama bitişi...",
    "times" : "kez",
    "Import Calendars" : "Takimleri İçe Aktar",
    "Import canceled" : "İçe aktarım iptal edildi",
    "Analyzing calendar" : "Takvim inceleniyor",
    "The file contains objects incompatible with the selected calendar" : "Dosya, seçili takvimle uyumsuz nesneler içeriyor",
    "New calendar" : "Yeni takvim",
    "Import scheduled" : "İçe aktarma zamanlandı",
    "Settings" : "Ayarlar",
    "Import calendar" : "Takvimi içe aktar",
    "No Calendars selected for import" : "İçe aktarılmak üzere hiç takvim seçilmemiş",
    "Primary CalDAV address" : "Birincil CalDAV adresi",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adresi"
},
"nplurals=2; plural=(n > 1);");

==> owncloud-app-calendar-1%3A1.3.2-3-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/l10n/tr.js <==
OC.L10N.register(
    "calendar",
    {
    "Calendar" : "Takvim",
    "Individual" : "Bireysel",
    "Group" : "Grup",
    "Resource" : "Kaynak",
    "Room" : "Oda",
    "Unknown" : "Bilinmeyen",
    "Required" : "Gerekli",
    "Optional" : "İsteğe Bağlı",
    "Does not attend" : "Katılmıyor",
    "You are in an unknown timezone ({tz}), falling back to UTC" : "Bilinmeyen bir zaman dilimindesiniz ({tz}), UTC'ye geri dönülüyor",
    "Please create a calendar first." : "Lütfen ilk olarak bir adres defteri oluşturun.",
    "New event" : "Yeni etkinli",
    "Attendees" : "Katılanlar",
    "Reminders" : "Hatırlatıcılar",
    "Repeating" : "Tekrarlama",
    "When shared show full event" : "Paylaşıldığında etkinliği göster",
    "When shared show only busy" : "Paylaşıldğında sadece meşgulleri göster",
    "When shared hide this event" : "Paylaşıldığında bu etkinliği gizle",
    "Please add a title!" : "Lütfen bir başlık ekleyin!",
    "Please select a calendar!" : "Lütfen bir takvim seçin!",
    "Global" : "Evrensel",
    "None" : "Hiçbiri",
    "Every day" : "Her gün",
    "Every week" : "Her hafta",
    "Every month" : "Her ay",
    "Every year" : "Her yıl",
    "never" : "hiçbir zaman",
    "after" : "şundan sonra",
    "At time of event" : "Olay anında",
    "5 minutes before" : "5 dakika önce",
    "10 minutes before" : "10 dakika önce",
    "15 minutes before" : "15 dakika önce",
    "30 minutes before" : "30 dakika önce",
    "1 hour before" : "1 saat önce",
    "2 hours before" : "2 saat önce",
    "Custom" : "Özel",
    "Audio" : "Ses",
    "E Mail" : "E-posta",
    "Pop up" : "Açılır pencere",
    "sec" : "saniye",
    "min" : "dk",
    "hours" : "saat",
    "days" : "gün",
    "week" : "hafta",
    "before" : "şundan önce",
    "start" : "başlangıç",
    "end" : "bitiş",
    "Editing reminders of unknown type not supported." : "Bilinmeyen tür hatırlatıcılarının düzenlenmesi desteklenmiyor.",
    "Week {number} of {year}" : "{year} yılının {number}. haftası",
    "Successfully imported" : "Başarıyla içe aktarıldı",
    "Partially imported, 1 failure" : "Kısmen içe aktarıldı, 1 başarısız",
    "Partially imported, {n} failures" : "Kısmen içe aktarıldı, {n} başarısız",
    "Audio alarm" : "Sesli alarm",
    "Pop-up" : "Açılır pencere",
    "E-Mail" : "E-Posta",
    "{type} {time} before the event starts" : "Etkinlik başlamadan {time} önce {type}",
    "{type} {time} before the event ends" : "Etkinlik bitmeden {time} önce {type}",
    "{type} {time} after the event starts" : "Etkinlik başladıktan {time} sonra {type}",
    "{type} {time} after the event ends" : "Etkinlik bittikten {time} sonra {type}",
    "{type} at the event's start" : "Etkinlik başlangıcında {type}",
    "{type} at the event's end" : "Etkinlik bitiminde {type}",
    "{type} at {time}" : "{time} zamanında {type}",
    "{calendar} shared by {owner}" : "{owner} tarafından paylaşılmış {calendar}",
    "Title of the Event" : "Etkinlik Başlığı",
    "starts" : "başlangıç",
    "ends" : "bitiş",
    "All day Event" : "Tüm gün etkinliği",
    "Delete" : "Sil",
    "Cancel" : "İptal",
    "More ..." : "Daha fazla ...",
    "Create" : "Oluştur",
    "Update" : "Güncelle",
    "Close" : "Kapat",
    "Location" : "Konum",
    "Description" : "Açıklama",
    "Export" : "Dışa aktar",
    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Üst yazılım hatası nedeniyle, takvim şu anda asset pipeline özelliğine destek veremiyor.",
    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Lütfen yöneticinizle iletişime geçip \"asset-pipeline.enabled\" yapılandırma seçeneğinin devre dışı bırakılmasını talep edin.",
    "Day" : "Gün",
    "Week" : "Hafta",
    "Month" : "Ay",
    "Today" : "Bugün",
    "Share Calendar" : "Takvimi Paylaş",
    "More" : "Daha fazla",
    "Edit" : "Düzenle",
    "CalDAV" : "CalDAV",
    "Share with users or groups" : "Kullanıcı ve gruplarla paylaş",
    "can edit" : "düzenleyebilir",
    "group" : "grup",
    "New Calendar" : "Yeni Takvim",
    "Subscriptions" : "Abonelikler",
    "New Subscription" : "Yeni Abonelik",
    "Url" : "Adres",
    "Edit event" : "Etkinliği düzenle",
    "Delete Event" : "Etkinliği Sil",
    "Save Event" : "Etkinliği Kaydet",
    "Time" : "Zaman",
    "Type" : "Tür",
    "Relative" : "Bağıl",
    "Absolute" : "Kesin",
    "Repeat" : "Tekrarla",
    "times every" : "defa, her",
    "Add" : "Ekle",
    "E-Mail address of attendee" : "Katılımcının e-posta adresi",
    "Please add your email address in the personal settings in order to add attendees." : "Lütfen katılımcıları eklemek için kişisel ayarlardan e-posta adresinizi ekleyin.",
    "from" : "başlangıç",
    "to" : "bitiş",
    "This event's repeating rule is not supported yet." : "Bu etkinliğin tekrarlanma kuralı henüz desteklenmiyor.",
    "Support for advanced rules will be added with subsequent updates." : "Gelişmiş kurallar sonraki güncellemelerde eklenecektir.",
    "Reset repeating rule" : "Tekrarlama kuralını sıfırla",
    "Repeat every ..." : "Tekrarlama koşulu...",
    "end repeat ..." : "tekrarlama bitişi...",
    "times" : "kez",
    "Import Calendars" : "Takimleri İçe Aktar",
    "Import canceled" : "İçe aktarım iptal edildi",
    "Analyzing calendar" : "Takvim inceleniyor",
    "The file contains objects incompatible with the selected calendar" : "Dosya, seçili takvimle uyumsuz nesneler içeriyor",
    "New calendar" : "Yeni takvim",
    "Import scheduled" : "İçe aktarma zamanlandı",
    "Settings" : "Ayarlar",
    "Import calendar" : "Takvimi içe aktar",
    "No Calendars selected for import" : "İçe aktarılmak üzere hiç takvim seçilmemiş",
    "Primary CalDAV address" : "Birincil CalDAV adresi",
    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adresi"
},
"nplurals=2; plural=(n > 1);");
